pub struct TargetTriple(/* private fields */);Expand description
The target triple a build is produced for (e.g. wasm32-unknown-unknown).
A newtype rather than a bare String so it cannot be transposed with the
profile or a path at a call site.
Implementations